package boshclient_test

import (
	"errors"

	"github.com/pivotal-cf/on-demand-service-broker/boshclient"
	"github.com/pivotal-cf/on-demand-service-broker/mockbosh"

	. "github.com/onsi/ginkgo"
	. "github.com/onsi/gomega"
)

var _ = Describe("deleting bosh deployments", func() {
	const deploymentName = "some-deployment"

	var (
		taskID    int
		deleteErr error

		contextID string
	)

	BeforeEach(func() {
		contextID = ""
	})

	JustBeforeEach(func() {
		taskID, deleteErr = c.DeleteDeployment(deploymentName, contextID, logger)
	})

	Context("when the authorization header cannot be generated", func() {
		BeforeEach(func() {
			authHeaderBuilder.BuildReturns("", errors.New("some-error"))
		})

		It("returns an error", func() {
			Expect(deleteErr).To(MatchError(ContainSubstring("some-error")))
		})
	})

	Context("when bosh accepts the delete request", func() {
		BeforeEach(func() {
			director.VerifyAndMock(
				mockbosh.DeleteDeployment(deploymentName).WithoutContextID().RedirectsToTask(90),
			)
		})

		It("calls the authorization header builder", func() {
			Expect(authHeaderBuilder.BuildCallCount()).To(BeNumerically(">", 0))
		})

		It("returns the bosh task ID", func() {
			Expect(taskID).To(Equal(90))
		})
	})

	Context("when bosh cannot find the deployment", func() {
		BeforeEach(func() {
			director.VerifyAndMock(
				mockbosh.DeleteDeployment(deploymentName).WithoutContextID().NotFound(),
			)
		})

		It("returns an error", func() {
			Expect(deleteErr).To(BeAssignableToTypeOf(boshclient.DeploymentNotFoundError{}))
		})
	})

	Context("when bosh cannot delete the deployment", func() {
		BeforeEach(func() {
			director.VerifyAndMock(
				mockbosh.DeleteDeployment(deploymentName).WithoutContextID().Fails("because reasons"),
			)
		})

		It("returns an error", func() {
			Expect(deleteErr).To(MatchError(ContainSubstring("expected status 302, was 500")))
		})
	})

	Context("when bosh context ID is provided", func() {
		BeforeEach(func() {
			contextID = "some-context-id"
			director.VerifyAndMock(
				mockbosh.DeleteDeployment(deploymentName).WithContextID(contextID).RedirectsToTask(90),
			)
		})

		It("includes the bosh context id header in delete request", func() {
			director.VerifyMocks()
		})
	})
})
