package boshclient

import "encoding/json"

type BoshTask struct {
	ID          int
	State       string
	Description string
	Result      string
	ContextID   string `json:"context_id,omitempty"`
}

type TaskStateType int

const (
	TaskDone TaskStateType = iota
	TaskIncomplete
	TaskFailed
	TaskUnknown
)

func (t BoshTask) ToLog() string {
	output, _ := json.Marshal(t)
	// json.Marshal will only return an error when the struct contains an
	// unsupported type. We know our struct does not, so we don't handle this
	// error.
	return string(output)
}

func (t BoshTask) StateType() TaskStateType {
	switch t.State {
	case BoshTaskDone:
		return TaskDone
	case BoshTaskProcessing, BoshTaskQueued, BoshTaskCancelling:
		return TaskIncomplete
	case BoshTaskCancelled, BoshTaskError, BoshTaskTimeout:
		return TaskFailed
	default:
		return TaskUnknown
	}
}
