package boshclient_test

import (
	"fmt"

	. "github.com/pivotal-cf/on-demand-service-broker/boshclient"

	. "github.com/onsi/ginkgo"
	. "github.com/onsi/ginkgo/extensions/table"
	. "github.com/onsi/gomega"
)

var _ = Describe("Task", func() {
	Describe("ToLog", func() {
		It("Returns a JSON serialised string representing the task", func() {
			task := BoshTask{
				ID:          1,
				State:       BoshTaskProcessing,
				Description: "snapshot deployment",
				Result:      "result-1",
			}

			Expect(task.ToLog()).To(Equal(fmt.Sprintf(
				`{"ID":1,"State":"%s","Description":"snapshot deployment","Result":"result-1"}`,
				BoshTaskProcessing,
			)))
		})
	})

	DescribeTable("StateType",
		func(state string, expected TaskStateType) {
			t := BoshTask{State: state}
			Expect(t.StateType()).To(Equal(expected))
		},
		Entry("when done", BoshTaskDone, TaskDone),
		Entry("when processing", BoshTaskProcessing, TaskIncomplete),
		Entry("when queued", BoshTaskQueued, TaskIncomplete),
		Entry("when cancelled", BoshTaskCancelled, TaskFailed),
		Entry("when cancelling", BoshTaskCancelling, TaskIncomplete),
		Entry("when error", BoshTaskError, TaskFailed),
		Entry("when timeout", BoshTaskTimeout, TaskFailed),
		Entry("when something unknown", "nonsense", TaskUnknown),
	)
})
