package broker

import (
	"fmt"
	"log"
)

func (b *Broker) redeploy(
	instanceID, planID string,
	operation OperationType,
	requestParams map[string]interface{},
	previousPlanID *string,
	boshContextID string,
	deployFunc DeployerFunc,
	logger *log.Logger,
) (int, error) {
	deploymentName := deploymentName(instanceID)
	oldManifest, found, err := b.boshClient.GetDeployment(deploymentName, logger)
	if err != nil {
		return 0, err
	}

	if !found {
		return 0, NewDeploymentNotFoundError(fmt.Errorf("bosh deployment '%s' not found", deploymentName))
	}

	boshTaskID, _, err := deployFunc(
		instanceID,
		planID,
		deploymentName,
		operation,
		requestParams,
		oldManifest,
		previousPlanID,
		boshContextID,
		logger,
	)
	if err != nil {
		return 0, err
	}

	return boshTaskID, nil
}
